Crate kcr_wgpolicyk8s_io

Crate kcr_wgpolicyk8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the wgpolicyk8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

wgpolicyk8s.io/v1alpha1

  • ClusterPolicyReport
  • PolicyReport

wgpolicyk8s.io/v1alpha2

  • ClusterPolicyReport
  • PolicyReport

wgpolicyk8s.io/v1beta1

  • ClusterPolicyReport
  • PolicyReport

Modules

v1alpha1
v1alpha2
v1beta1