This crate contains kube-rs compatible bindings for Kubernetes custom resources for the wgpolicyk8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
wgpolicyk8s.io/v1alpha1
ClusterPolicyReportPolicyReport
wgpolicyk8s.io/v1alpha2
ClusterPolicyReportPolicyReport
wgpolicyk8s.io/v1beta1
ClusterPolicyReportPolicyReport